==> nextcloud-22.1.1.tgz: nextcloud/apps/theming/l10n/it.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Caricamento anteprima...",
    "Saved" : "Salvato",
    "Admin" : "Amministratore",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "Name cannot be empty" : "Il nome non può essere vuoto",
    "The given name is too long" : "Questo nome è troppo lungo",
    "The given web address is too long" : "Questo indirizzo web è troppo lungo",
    "The given web address is not a valid URL" : "L'indirizzo web specifico non è un URL valido",
    "The given legal notice address is too long" : "L'indirizzo dell'avviso legale specificato è troppo lungo",
    "The given legal notice address is not a valid URL" : "L'indirizzo delle specifiche note legali non è un URL valido",
    "The given privacy policy address is too long" : "L'indirizzo dello specifico criterio di riservatezza è troppo lungo",
    "The given privacy policy address is not a valid URL" : "L'indirizzo dello specifico criterio di riservatezza non è un URL valido",
    "The given slogan is too long" : "Questo slogan è troppo lungo",
    "The given color is invalid" : "Questo colore non è valido",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è  stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "No file uploaded" : "Nessun file caricato",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Stai già utilizzando un tema personalizzato. Le impostazioni dell'applicazione dei temi potrebbero essere sovrascritte.",
    "Theming" : "Tema",
    "Legal notice" : "Avviso legale",
    "Privacy policy" : "Criterio di riservatezza",
    "Adjust the Nextcloud theme" : "Modifica il tema di Nextcloud",
    "Open documentation" : "Apri la documentazione",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
    "Name" : "Nome",
    "Reset to default" : "Ripristina valori predefiniti",
    "Web link" : "Collegamento web",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Colore",
    "Logo" : "Logo",
    "Upload new logo" : "Carica nuovo logo",
    "Login image" : "Immagine di accesso",
    "Upload new login background" : "Carica nuovo sfondo di accesso",
    "Remove background image" : "Rimuovi immagine di sfondo",
    "Advanced options" : "Opzioni avanzate",
    "Legal notice link" : "Collegamento avviso legale",
    "Privacy policy link" : "Collegamento criteri di riservatezza",
    "Header logo" : "Logo dell'intestazione",
    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Carica nuova favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione Imagemagick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.5.tgz: nextcloud/apps/theming/l10n/it.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Caricamento anteprima...",
    "Admin" : "Amministratore",
    "Saved" : "Salvato",
    "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
    "Name cannot be empty" : "Il nome non può essere vuoto",
    "The given name is too long" : "Questo nome è troppo lungo",
    "The given web address is too long" : "Questo indirizzo web è troppo lungo",
    "The given web address is not a valid URL" : "L'indirizzo web specifico non è un URL valido",
    "The given legal notice address is too long" : "L'indirizzo dell'avviso legale specificato è troppo lungo",
    "The given legal notice address is not a valid URL" : "L'indirizzo delle specifiche note legali non è un URL valido",
    "The given privacy policy address is too long" : "L'indirizzo dello specifico criterio di riservatezza è troppo lungo",
    "The given privacy policy address is not a valid URL" : "L'indirizzo dello specifico criterio di riservatezza non è un URL valido",
    "The given slogan is too long" : "Questo slogan è troppo lungo",
    "The given color is invalid" : "Questo colore non è valido",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è  stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "No file uploaded" : "Nessun file caricato",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Stai già utilizzando un tema personalizzato. Le impostazioni dell'applicazione dei temi potrebbero essere sovrascritte.",
    "Theming" : "Tema",
    "Appearance and accessibility" : "Aspetto e accessibilità",
    "Dark theme with high contrast mode" : "Tema scuro con modalità di contrasto elevato",
    "Enable dark high contrast mode" : "Abilita la modalità scuro ad alto contrasto",
    "Similar to the high contrast mode, but with dark colours." : "Simile alla modalità a contrasto elevato, ma con colori scuri.",
    "Dark theme" : "Tema scuro",
    "Enable dark theme" : "Abilita il tema scuro",
    "Dyslexia font" : "Carattere per dislessici",
    "Enable dyslexia font" : "Abilita il carattere per dislessici",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic è un carattere libero progettato per mitigare alcuni dei comuni errori di lettura causati dalla dislessia.",
    "High contrast mode" : "Modalità ad alto contrasto",
    "Enable high contrast mode" : "Abilita la modalità ad alto contrasto",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Una modalità ad alto contrasto per semplificare la tua navigazione. La qualità visiva sarà ridotta per incrementare la chiarezza.",
    "Light theme" : "Tema leggero",
    "Enable the default light theme" : "Abilita il tema leggero predefinito",
    "The default light appearance." : "L'aspetto predefinito del tema leggero.",
    "Legal notice" : "Avviso legale",
    "Privacy policy" : "Criterio di riservatezza",
    "Adjust the Nextcloud theme" : "Modifica il tema di Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accesso universale è molto importante per noi. Seguiamo gli standard web e cerchiamo di rendere tutto utilizzabile anche senza mouse, e programmi di assistenza come i lettori dello schermo. Il nostro obiettivo è la compatibilità con la {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 a livello AA, con il tema ad alto contrasto anche a livello AAA. ",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se trovi qualsiasi problema, non esitare a segnalarlo sul {issuetracker}nostro sistema di segnalazione dei bug{linkend}. E se vuoi partecipare, unisciti alla {designteam}nostra squadra di progettazione{linkend}!",
    "Open documentation" : "Apri la documentazione",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La gestione dei temi rende semplice la personalizzazione dell'aspetto della tua istanza e dei client supportati. Ciò sarà visibile a tutti gli utenti.",
    "Name" : "Nome",
    "Reset to default" : "Ripristina valori predefiniti",
    "Web link" : "Collegamento web",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Colore",
    "Logo" : "Logo",
    "Upload new logo" : "Carica nuovo logo",
    "Login image" : "Immagine di accesso",
    "Upload new login background" : "Carica nuovo sfondo di accesso",
    "Remove background image" : "Rimuovi immagine di sfondo",
    "Advanced options" : "Opzioni avanzate",
    "Legal notice link" : "Collegamento avviso legale",
    "Privacy policy link" : "Collegamento criteri di riservatezza",
    "Header logo" : "Logo dell'intestazione",
    "Upload new header logo" : "Carica nuovo logo dell'intestazione",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Carica nuova favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installa l'estensione Imagemagick di PHP con supporto per le immagini SVG per generare automaticamente favicon basate sul logo caricato e sul colore."
},
"nplurals=2; plural=(n != 1);");
